==> haskell-xml-conduit-1.8.0.1-102-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.8.0.1
id: xml-conduit-1.8.0.1-7DOl81vm7wFHtD0kYrdBe
key: xml-conduit-1.8.0.1-7DOl81vm7wFHtD0kYrdBe
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
abi: e6160741fc8cac36553c1a3c67441f3f
exposed: True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
hidden-modules: Text.XML.Stream.Token
import-dirs: /usr/lib/ghc-8.6.5/site-local/xml-conduit-1.8.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/xml-conduit-1.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/xml-conduit-1.8.0.1
hs-libraries: HSxml-conduit-1.8.0.1-7DOl81vm7wFHtD0kYrdBe
depends:
    attoparsec-0.13.2.3-7zk58GWWjTj9W2Qd2JktwB base-4.12.0.0
    blaze-html-0.9.1.2-3rCj4yYYlH244V10MP4Bb5
    blaze-markup-0.8.2.3-ATcS0IRQcDMCxhB8vW9N1d bytestring-0.10.8.2
    conduit-1.3.1.2-KNywdU6deAEKB3TItOoWtt
    conduit-extra-1.3.4-DwOMiGU8D2ECbS5X5nzGB1 containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 deepseq-1.4.4.0
    resourcet-1.2.2-2dmcTwjPeuF8zenLvwytIP text-1.2.3.1
    transformers-0.5.6.2 xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-conduit-1.8.0.1-104-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-xml-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: xml-conduit
version: 1.8.0.1
id: xml-conduit-1.8.0.1-8BXA8xxPwpUKTC05y85ve4
key: xml-conduit-1.8.0.1-8BXA8xxPwpUKTC05y85ve4
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>, Aristid Breitkreuz <aristidb@googlemail.com>
stability: Stable
homepage: http://github.com/snoyberg/xml
synopsis: Pure-Haskell utilities for dealing with XML with the conduit package.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/xml-conduit>.
category: XML, Conduit
abi: 331f1c81ca751298ae094bc35d2a4fa3
exposed: True
exposed-modules:
    Text.XML Text.XML.Cursor Text.XML.Cursor.Generic
    Text.XML.Stream.Parse Text.XML.Stream.Render Text.XML.Unresolved
hidden-modules: Text.XML.Stream.Token
import-dirs: /usr/lib/ghc-8.6.5/site-local/xml-conduit-1.8.0.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/xml-conduit-1.8.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/xml-conduit-1.8.0.1
hs-libraries: HSxml-conduit-1.8.0.1-8BXA8xxPwpUKTC05y85ve4
depends:
    attoparsec-0.13.2.3-8w0M5Ys1O3I8OHsDdXIpYC base-4.12.0.0
    blaze-html-0.9.1.2-46zU1Jl1PZV3zFjN4bwuoM
    blaze-markup-0.8.2.3-ATcS0IRQcDMCxhB8vW9N1d bytestring-0.10.8.2
    conduit-1.3.1.2-FrtJMTY3M2CAC8GVZl6Z8t
    conduit-extra-1.3.4-IEDUhE0Yi5H3r73EQQ4eKT containers-0.6.0.1
    data-default-class-0.1.2.0-1aigY0ifYUs4kfvMygEld7 deepseq-1.4.4.0
    resourcet-1.2.2-B6MNSo3GKFWL8hVHO97lMf text-1.2.3.1
    transformers-0.5.6.2 xml-types-0.3.6-56MQ2lbfiw31ognZ51DOah
haddock-interfaces: /usr/share/doc/haskell-xml-conduit/html/xml-conduit.haddock
haddock-html: /usr/share/doc/haskell-xml-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
